﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.Core;

namespace WpfApp3
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private async void mapView_Loaded(object sender, RoutedEventArgs e)
        {
            mapView.MapUnit = ThinkGeo.Core.GeographyUnit.Meter;


            // Create a new overlay that will hold our new layer and add it to the map.
            LayerOverlay coyoteSightingsOverlay = new LayerOverlay();
            // mapView.Overlays.Add(coyoteSightingsOverlay);

            // Create the new layer and set the projection as the data is in srid 2276 as our background is srid 3857 (spherical mercator).
            SqlServerFeatureLayer coyoteSightingsLayer = new SqlServerFeatureLayer("Server=sampledatabases.thinkgeo.com;Database=ThinkGeoSamples;User Id=thinkgeouser;Password=dkjGk$%*7kS82hks;", "frisco_coyote_sightings", "id");

            coyoteSightingsLayer.FeatureSource.ProjectionConverter = new ProjectionConverter(2276, 3857);

            // Add the layer to the overlay we created earlier.
            coyoteSightingsOverlay.Layers.Add("Coyote Sightings", coyoteSightingsLayer);

            // Set a point style to zoom level 1 and then apply it to all zoom levels up to 20.
            coyoteSightingsLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, 12, GeoBrushes.Black, new GeoPen(GeoColors.White, 1));
            coyoteSightingsLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;


            PrinterInteractiveOverlay printerOverlay = new PrinterInteractiveOverlay();


            MapPrinterLayer mapPrinterLayer = new MapPrinterLayer(new Layer[] { coyoteSightingsLayer },
                new RectangleShape(-10784283.099060204, 3918532.598821122, -10781699.527518518, 3916820.409397046), GeographyUnit.Meter);

            PagePrinterLayer pageLayer = new PagePrinterLayer(PrinterPageSize.AnsiA, PrinterOrientation.Portrait);
            printerOverlay.PrinterLayers.Add("pageLayer", pageLayer);

            //// Style the pageLayer to appear to look like a piece of paper
            pageLayer.BackgroundMask = AreaStyle.CreateSimpleAreaStyle(GeoColors.White, GeoColors.Black);


            //// Set the position of the map using the pageLayer's centerPoint
            var pageCenter = pageLayer.GetPosition().GetCenterPoint();
            mapPrinterLayer.SetPosition(7.5, 5, pageCenter.X, pageCenter.Y + 1.75, PrintingUnit.Inch);

            printerOverlay.PrinterLayers.Add(mapPrinterLayer);

            //  printerOverlay.PrinterLayers.Add("pageLayer", pageLayer);


            // Add the printerOverlay to the map
            mapView.InteractiveOverlays.Add("printerOverlay", printerOverlay);
            var extent = await Task.Run(() => OpenLayer(pageLayer, mapPrinterLayer));

            // Set the map view current extent to a bounding box that shows just a few sightings.  
            mapView.CurrentExtent = extent;

            mapView.Refresh();

        }

        public async Task<RectangleShape> OpenLayer(PagePrinterLayer pageLayer, MapPrinterLayer printLayer)
        {
            pageLayer.Open();
            printLayer.Open();
            return pageLayer.GetBoundingBox();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
          
        }
    }
}
